@@ -51,8 +51,8 @@ public class PhraseLeader
 	 *
 	 * Now, "chair" can be identified as the leader of "(NP the red chair)"
 	 * because there is a binary relation: "amod(chair, red)" that 
-	 * identifies * chair.  However, "(NP the chair)" has no such binary 
-	 * relation, and so instead, we look for either "DEFINITE-FLAG(chair, T)"
+	 * identifies chair.  However, "(NP the chair)" has no such binary 
+	 * relation, and so instead, we look for either "definite-FLAG(chair, T)"
 	 * or for "noun_number(chair, singular)" to identify "chair".
 	 */
 	private static void _phraseHeads(FeatureNode fn)
@@ -61,6 +61,13 @@ public class PhraseLeader
 		if (fn_name_source == null) return;
 		FeatureNode phr = fn_name_source.get("phr-head");
 		if (phr == null) return;
+
+		// If already set, return. Do this because we should trust the
+		// binary relations more than the unary ones; and the binary
+		// ones are checked first. (The unary relations can accidentally
+		// over-ride a correct binary ID.)
+		if (null != phr.get("phr-leader")) return;
+
 		if (0 < DEBUG) System.err.println("Debug: set leader=" + fn.get("name") +
 		                " for phrase=" + PhraseTree.toString(fn_name_source));
 		phr.set("phr-leader", fn);
@@ -70,7 +77,7 @@ public class PhraseLeader
 	{
 		public Boolean UnaryRelationCB(FeatureNode from, String rel)
 		{
-			if (rel.equals("DEFINITE-FLAG") || rel.equals("noun_number"))
+			if (rel.equals("definite-FLAG") || rel.equals("noun_number"))
 			{
 				_phraseHeads(from);
 			}
